summaryrefslogtreecommitdiffstats
path: root/kxsldbg/kxsldbgpart/xsldbginspector.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kxsldbg/kxsldbgpart/xsldbginspector.cpp')
-rw-r--r--kxsldbg/kxsldbgpart/xsldbginspector.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/kxsldbg/kxsldbgpart/xsldbginspector.cpp b/kxsldbg/kxsldbgpart/xsldbginspector.cpp
index b6a8f6df..db6fcb58 100644
--- a/kxsldbg/kxsldbgpart/xsldbginspector.cpp
+++ b/kxsldbg/kxsldbgpart/xsldbginspector.cpp
@@ -44,15 +44,15 @@ static TQPixmap uic_load_pixmap_XsldbgInspector( const TQString &name )
return pix;
}
/*
* Constructs a XsldbgInspector which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* true to construct a modal dialog.
*/
-XsldbgInspector::XsldbgInspector( XsldbgDebugger *debugger, TQWidget* parent,
+XsldbgInspector::XsldbgInspector( XsldbgDebugger *debugger, TQWidget* tqparent,
const char* name, bool modal, WFlags fl )
- : TQDialog( parent, name, modal, fl )
+ : TQDialog( tqparent, name, modal, fl )
{
Q_CHECK_PTR(debugger);
this->debugger = debugger;
@@ -159,7 +159,7 @@ XsldbgInspector::XsldbgInspector( XsldbgDebugger *debugger, TQWidget* parent,
XsldbgInspector::~XsldbgInspector()
{
debugger = 0L;
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
@@ -44,15 +44,15 @@ static TQPixmap uic_load_pixmap_XsldbgInspector( const TQString &name )
}
/*
- * Constructs a XsldbgInspector which is a child of 'parent', with the
+ * Constructs a XsldbgInspector which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*